pub struct Environment { /* private fields */ }Expand description
Variable environment for scoping
Implementations
Sourceimpl Environment
impl Environment
Sourcepub fn with_parent(parent: Environment) -> Self
pub fn with_parent(parent: Environment) -> Self
Creates a new child environment
Sourcepub fn lookup(&self, name: &str) -> Result<&Value>
pub fn lookup(&self, name: &str) -> Result<&Value>
Looks up a variable in this scope or parent scopes
Sourcepub fn is_defined(&self, name: &str) -> bool
pub fn is_defined(&self, name: &str) -> bool
Checks if a variable is defined
Sourcepub fn update(&mut self, name: &str, value: Value) -> Result<()>
pub fn update(&mut self, name: &str, value: Value) -> Result<()>
Updates a variable in the current scope or parent scopes
Sourcepub fn merge(&mut self, other: Environment)
pub fn merge(&mut self, other: Environment)
Merges another environment into this one