estimate_stack_depth

Function estimate_stack_depth 

pub fn estimate_stack_depth(ops: &[OpCode]) -> usize
Statically estimate the maximum stack depth required to execute ops.

Each opcode is modelled as a pure delta on the stack pointer. The function returns the maximum depth seen.