pub fn close_ring(coords: &[Coordinate]) -> Result<Vec<Coordinate>>Expand description
Closes an unclosed ring by adding the first point at the end
pub fn close_ring(coords: &[Coordinate]) -> Result<Vec<Coordinate>>Closes an unclosed ring by adding the first point at the end