pub fn contains<T: ContainsPredicate>(a: &T, b: &T) -> Result<bool>Expand description
Tests if geometry A contains geometry B
Geometry A contains B if:
- No points of B lie in the exterior of A
- At least one point of the interior of B lies in the interior of A
Arguments
a- Container geometryb- Contained geometry
Returns
True if A contains B
Errors
Returns error if geometries are invalid