crosses

Function crosses 

pub fn crosses<T: CrossesPredicate>(a: &T, b: &T) -> Result<bool>
Tests if one geometry crosses another

Two geometries cross if:

  • They have some but not all interior points in common
  • The dimension of the intersection is less than the maximum dimension of the two geometries

Arguments

  • a - First geometry
  • b - Second geometry

Returns

True if geometries cross

Errors

Returns error if geometries are invalid