envelope_polygon

Function envelope_polygon 

pub fn envelope_polygon(polygon: &Polygon) -> Result<Polygon>
Computes the envelope of a polygon

Returns a rectangular polygon that bounds the input polygon.

Arguments

  • polygon - Input polygon

Returns

Polygon representing the envelope

Errors

Returns error if polygon is invalid or envelope creation fails