pub struct InverseResult {
pub s12: f64,
pub azi1: f64,
pub azi2: f64,
pub s12_area: f64,
}Expand description
Result of the inverse geodesic problem between two points.
Fields
s12: f64Geodesic distance in meters
azi1: f64Forward azimuth at point 1 (degrees, clockwise from north)
azi2: f64Forward azimuth at point 2 (degrees, clockwise from north)
s12_area: f64Area element between the geodesic and the equator (square meters)