pub struct Pool<T> { /* private fields */ }Expand description
Generic object pool for reusable objects
The pool maintains a collection of reusable objects to reduce allocation
overhead. Objects are returned to the pool automatically via PoolGuard.
Implementations