pub struct PoolGuard<'a, T> { /* private fields */ }Expand description
RAII guard that returns an object to the pool when dropped
This ensures objects are automatically returned to the pool even if an error occurs or early return happens.
The guard uses ManuallyDrop internally to avoid double-drop issues
when converting to the inner value.
Implementations
Sourceimpl<'a, T> PoolGuard<'a, T>
impl<'a, T> PoolGuard<'a, T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the guard and returns the inner object without returning to pool