Function envelope_polygon
Source pub fn envelope_polygon(polygon: &Polygon) -> Result<Polygon>
Computes the envelope of a polygon
Returns a rectangular polygon that bounds the input polygon.
Arguments
Returns
Polygon representing the envelope
Errors
Returns error if polygon is invalid or envelope creation fails