pub struct RansacLineModel {
pub a: f64,
pub b: f64,
pub c: f64,
}Expand description
A 2D line in implicit form a x + b y + c = 0 with the normal (a, b)
normalized so that a² + b² = 1.
Fields
a: f64x coefficient of the normal.
b: f64y coefficient of the normal.
c: f64Signed offset.
Implementations
Sourceimpl RansacLineModel
impl RansacLineModel
Sourcepub fn from_two_points(p1: Point, p2: Point) -> Option<Self>
pub fn from_two_points(p1: Point, p2: Point) -> Option<Self>
Builds a line through two points.
Returns None when the points are coincident (within
DEGENERATE_EPSILON). The normal (a, b) is perpendicular to the
direction p2 - p1.
Sourcepub fn distance_to(&self, p: Point) -> f64
pub fn distance_to(&self, p: Point) -> f64
Perpendicular distance from a point to the line (a, b normalized).
Sourcepub fn point_on_line(&self) -> (f64, f64)
pub fn point_on_line(&self) -> (f64, f64)
The point on the line closest to the origin: (-a*c, -b*c).